"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.fetchCloud = void 0;
const cloud_api_1 = require("@cloudbase/cloud-api");
const tcb_1 = require("./tcb");
const utils_1 = require("./utils");
const defaultOptions = {
    service: 'lowcode',
    version: '2021-01-08',
    timeout: 10000,
    data: {},
    capitalizeDataKey: true,
};
/**
 * 请求云API
 * @param params 配置参数
 */
async function fetchCloud(params) {
    try {
        const { TENCENTCLOUD_SECRETID, TENCENTCLOUD_SECRETKEY } = tcb_1.tcb.getCloudbaseContext();
        const newOptions = Object.assign({}, defaultOptions, params);
        const service = cloud_api_1.CloudApiService.getInstance({
            service: newOptions.service,
            version: newOptions.version,
            credential: {
                secretId: TENCENTCLOUD_SECRETID,
                secretKey: TENCENTCLOUD_SECRETKEY,
            },
            timeout: newOptions.timeout,
        });
        const resp = await service.request(params.action, newOptions.capitalizeDataKey ? utils_1.capitalizeKey(newOptions.data) : newOptions.data);
        return resp;
    }
    catch (error) {
        if (error.original) {
            throw new utils_1.TCBError(error.original.Code, error.original.Message);
        }
        throw error;
    }
}
exports.fetchCloud = fetchCloud;
