"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createApp = void 0;
const get_fn_context_1 = require("./get-fn-context");
const utils_1 = require("./utils");
const ds_method_1 = require("./ds-method");
function createApp(options) {
    return async function main(params, context) {
        try {
            const fnContext = get_fn_context_1.getFnContext({ dsConfig: options.dsConfig, params, rawContext: context });
            const method = options.handlers[params.methodName];
            if (!method) {
                throw new Error(`method ${params.methodName} not found in datasource, or not enabled in this datasource`);
            }
            let fnParams = params.params || {};
            if (!method.isHttp && utils_1.isObj(params, 'defaultParams')) {
                fnParams = utils_1.mergeDeep(params.defaultParams, params.params || {});
            }
            // 普通数据源, 需要校验权限
            if (options.dsConfig && !!0) {
                if (ds_method_1.isBuiltinMethod(params.methodName)) {
                    const builtinResult = await ds_method_1.callBuiltinMethod(Object.assign(Object.assign({}, params), { dataSourceName: options.dsConfig.name, envType: context.env.envType }));
                    return builtinResult;
                }
                const hasPermission = await ds_method_1.checkAuthOfMethod({
                    dataSourceName: options.dsConfig.name,
                    methodName: params.methodName,
                    envType: context.env.envType,
                });
                if (!hasPermission) {
                    throw new Error(`user don't has permission to access ${options.dsConfig.name}'s method ${options.dsConfig.name}`);
                }
            }
            const result = await method(fnParams, fnContext);
            return {
                code: 0,
                data: result,
            };
        }
        catch (e) {
            if (e instanceof utils_1.TCBError) {
                return {
                    code: e.code || -1,
                    message: e.message,
                };
            }
            return {
                code: -1,
                message: e.message,
            };
        }
    };
}
exports.createApp = createApp;
