"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.callBuiltinMethod = exports.checkAuthOfMethod = exports.normalizeBuiltinMethodName = exports.isBuiltinMethod = void 0;
/**
 * 数据源方法相关方法
 */
const weda_api_1 = require("./weda-api");
const BUILTIN_METHOD_NAMES = ['create', 'delete', 'update', 'getItem',
    'getList', 'getRecords'];
const BUILTIN_NAME_REG = /^weda\.+/;
/** 是否为内置云函数 */
function isBuiltinMethod(name) {
    return BUILTIN_NAME_REG.test(name) || BUILTIN_METHOD_NAMES.includes(name);
}
exports.isBuiltinMethod = isBuiltinMethod;
/**
 * 标准化内置云函数名称
 */
function normalizeBuiltinMethodName(name) {
    if (BUILTIN_NAME_REG.test(name))
        return name;
    return `weda${name[0].toUpperCase()}${name.slice(1)}`;
}
exports.normalizeBuiltinMethodName = normalizeBuiltinMethodName;
function checkAuthOfMethod(params) {
    return weda_api_1.fetchWeda({
        action: 'AuthCustomMethod',
        envType: params.envType,
        data: {
            method: params.methodName,
            dataSourceName: params.dataSourceName,
        },
    }).then(res => res.Auth);
}
exports.checkAuthOfMethod = checkAuthOfMethod;
function callBuiltinMethod(params) {
    return weda_api_1.fetchWeda({
        action: 'ProcessInternalMethod',
        envType: params.envType,
        data: {
            method: normalizeBuiltinMethodName(params.methodName),
            dataSourceName: params.dataSourceName,
            params: params.params,
        },
    }).then(res => res.Data);
}
exports.callBuiltinMethod = callBuiltinMethod;
