"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getFnContext = void 0;
/**
 * 获取单个数据源云函数的context
 */
const tcb_1 = require("./tcb");
const utils_1 = require("./utils");
function getFnContext(config) {
    var _a, _b;
    const envObj = utils_1.getCloudbaseContext(config.rawContext);
    const envTypeInfo = getEnvType(config);
    const dsFullName = config.dsConfig && utils_1.getDsFullName(config.dsConfig, envTypeInfo.isPreview);
    // 目前仅内建数据源才有数据库
    const hasDb = ((_a = config.dsConfig) === null || _a === void 0 ? void 0 : _a.type) === 'database';
    const envInfo = Object.assign(Object.assign({}, envTypeInfo), { openId: envObj.WX_OPENID, 
        // @ts-ignore
        fromOpenId: envObj.WX_FROM_OPENID, appId: envObj.WX_APPID, 
        // @ts-ignore
        fromAppId: envObj.WX_FROM_APPID, uid: envObj.TCB_UUID, customUserId: envObj.TCB_CUSTOM_USER_ID || '', isAnonymous: envObj.TCB_ISANONYMOUS_USER === 'true', dataSourceName: (_b = config.dsConfig) === null || _b === void 0 ? void 0 : _b.name, dataSourceFullName: dsFullName, envId: envObj.TCB_ENV });
    // 自定义操作的context
    const cfContext = {
        cloudbase: tcb_1.tcb,
        app: tcb_1.app,
        auth: tcb_1.auth,
        env: envInfo,
        envInfo,
        database: tcb_1.db,
        weixin: getWxCloudInfo(config.params),
        defaultParams: config.params.defaultParams,
        collection: hasDb && dsFullName ? tcb_1.db.collection(dsFullName) : undefined,
        wedaTarget: config.params.wedaTarget,
    };
    utils_1.setConfig({ wedaTarget: cfContext.wedaTarget });
    return cfContext;
}
exports.getFnContext = getFnContext;
/**
 * 获取环境类型信息, 返回 { isPreview, envType }
 *  优先使用 config.isPreview 判断环境类型, 再使用环境变量, 最后才使用 params 中的 envType
 */
function getEnvType(config) {
    let isPreview;
    let { envType } = config.params;
    if (typeof config.isPreview === 'boolean') {
        isPreview = config.isPreview;
    }
    if (isPreview === undefined && process.env.NODE_ENV) {
        isPreview = true;
    }
    if (isPreview === undefined) {
        if (envType) {
            isPreview = envType === 'prod';
            return {
                isPreview,
                envType,
            };
        }
        isPreview = true;
    }
    envType = isPreview ? 'pre' : 'prod';
    return {
        isPreview,
        envType,
    };
}
function getWxCloudInfo(params) {
    const wxReg = /^wx_/;
    const wxKeys = Object.keys(params).filter(k => wxReg.test(k));
    if (!wxKeys.length)
        return null;
    const weixin = {};
    return wxKeys.reduce((acc, cur) => {
        acc[cur.replace(wxReg, '')] = params[cur];
        return acc;
    }, weixin);
}
