import tcb from '@cloudbase/node-sdk';
/**
 * 数据源生成的云函数入参
 */
export interface ICloudFnParams {
    methodName: string;
    defaultParams: any;
    params: any;
    /**
     * 调用的引用环境类型
     *  pre: 预览环境
     *  prod: 正式环境
     *
     * 在云开发的环境变量中若无法通过 IS_PREVIEW 当前环境是否为预览, 则使用该参数
     */
    envType: 'pre' | 'prod';
    /**
     * 请求的微搭后台接入层地址, 可通过设置为 prod/pre 来指定地址
     * 可以是下边三个值
     *  'prod' 正式地址
     *  'pre' 预发地址
     *  url 任意一个url
     */
    wedaTarget?: string;
    /** 其他额外信息 */
    [k: string]: any;
}
/** 环境变量信息 */
export interface IEnvInfo {
    openId?: string;
    /** 微信中, 多个小程序共享环境时, 来源用户的openId, 实际使用时应当优先使用该值 */
    fromOpenId?: string;
    appId?: string;
    /** 微信中, 多个小程序共享环境时, 来源小程序的appId, 实际使用时应当优先使用该值 */
    fromAppId?: string;
    uid?: string;
    customUserId?: string;
    isAnonymous: boolean;
    /** 数据源名称, 用户在数据源管理中创建的数据源才有该属性 */
    dataSourceName?: string;
    /** 数据源完整名称, 带数据源ID, 为部署后底层(云函数/数据库)使用使用的标志 */
    dataSourceFullName?: string;
    /** 是否为预览环境 */
    isPreview: boolean;
    /**
     * 环境类型
     *  pre: 预览环境
     *  prod: 正式环境
     */
    envType: 'prod' | 'pre';
    /** 云开发环境ID */
    envId: string;
}
/** 数据源函数执行的 context */
export interface IFnContext {
    cloudbase: typeof tcb;
    app: tcb.CloudBase;
    auth: ReturnType<tcb.CloudBase['auth']>;
    database: tcb.Database.Db;
    env: IEnvInfo;
    /**
     * 环境变量信息
     * @deprecated 使用 env 替代
     */
    envInfo: IEnvInfo;
    /** 通过微信 cloudID 获取的信息 */
    weixin: Record<string, any> | null;
    collection?: tcb.Database.CollectionReference;
    /** 数据源请求携带的默认参数 */
    defaultParams: any;
    /** 请求的微搭后台接入层地址, 可通过设置为 prod/pre 来指定地址 */
    wedaTarget?: string;
}
/** 数据源函数的参数 */
export declare type IFnParams = Record<string | number, any>;
/** 数据源方法类型 */
export declare type IDsFn = {
    /** http 类型方法需有该属性 */
    isHttp?: boolean;
    (params: IFnParams, context: IFnContext): Promise<any>;
};
/** 数据源基础信息 */
export interface IDsKeyInfo {
    /** 数据源ID */
    id: string;
    /** 数据源名称 */
    name: string;
    /** 数据源类型 database, cloud-integration */
    type: string;
}
