import cloudbase from '@cloudbase/node-sdk';
import { IDsKeyInfo } from './types';
interface IConfig {
    /** weda 接入层地址 */
    wedaTarget: string;
}
declare type IConfigKey = keyof IConfig;
/**
 * node-sdk 内部共享的配置信息
 *  !!TODO: 在云函数中, 单进程, 信息不共享, 不会出现数据串的问题, 但放到云托管中, 则会有问题
 */
declare const config: Partial<IConfig>;
/**
 * 设置配置, 应当只在 get-fn-context 中调用
 */
export declare function setConfig(cfg: Partial<IConfig>): void;
/**
 * 获取配置, !!! 调用前必须确保已经调用过 getFnContext !!!
 */
export declare function getConfig(): typeof config;
export declare function getConfig(key: IConfigKey): IConfig[IConfigKey];
/**
 * 解析云函数的 context
 *  为保证能获取到完整的context信息, 应当保证在第一次调用时有传入 context
 * @param context tcb 云函数的context, 即 main 函数的第二个参数
 */
export declare function getCloudbaseContext(context?: any): cloudbase.ICompleteCloudbaseContext;
/**
 * 将对象的key的首字母转换为大写, 适应 yunapi 的命名风格
 *  { userName: 'xxx', id: 'xxx' } => { UserName: 'xxx', Id: 'xxxx'}
 */
export declare function capitalizeKey(obj: Record<string, any>): Record<string, any>;
/**
 * 将对象的 key 转换为全小写
 *  for http header usage
 */
export declare function lowercaseKey(obj: Record<string, any>): Record<string, any>;
/**
 * 获取数据源完整名称, 该名称用于发布后的tcb云函数, 也用于tcb的数据库名称
 * @param ds 数据源关键信息
 * @param isPreview 是否预览
 * @returns 数据源表名
 */
export declare function getDsFullName(ds: IDsKeyInfo, isPreview: boolean): string;
/** 预置的错误对象, 可用该对象抛出自定义错误代码及错误信息 */
export declare class TCBError extends Error {
    code: number | string;
    constructor(code: number | string, message: string);
}
/**
 * Performs a deep merge of `source` into `target`.
 * Mutates `target` only but not its objects and arrays.
 *
 * @author inspired by [jhildenbiddle](https://stackoverflow.com/a/48218209).
 */
export declare function mergeDeep(target: any, source: any): any;
/** 是否为对象(非数组) */
export declare function isObj(obj: any, key?: string): boolean;
/** 获取用户来源信息 */
export declare function getUserSource(): {
    uid: string | undefined;
    /** uid 类型, 1.tcb 2.微信 3.企业微信 4.weda内部 */
    source: number;
} | undefined;
export {};
