"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.fetchWeda = void 0;
const cloud_api_1 = require("@cloudbase/cloud-api");
const utils_1 = require("./utils");
const defaultOptions = {
    data: {},
    capitalizeDataKey: true,
};
/**
 * 请求Weda后台接口
 * @param params 配置参数
 */
async function fetchWeda(params) {
    try {
        const userSource = utils_1.getUserSource();
        const newParams = Object.assign({}, defaultOptions, params, {
            uid: (userSource === null || userSource === void 0 ? void 0 : userSource.uid) || '',
            source: (userSource === null || userSource === void 0 ? void 0 : userSource.source) || '',
        });
        if (!newParams.uid || !newParams.source) {
            throw new utils_1.TCBError(-1, '[fetchWeda]unable to determine user uid or source');
        }
        const envInfo = utils_1.getCloudbaseContext();
        const requestParams = Object.assign(Object.assign({}, newParams), { envId: envInfo.SCF_NAMESPACE, credentials: {
                secretId: envInfo.TENCENTCLOUD_SECRETID,
                secretKey: envInfo.TENCENTCLOUD_SECRETKEY,
                sessionToken: envInfo.TENCENTCLOUD_SESSIONTOKEN,
            }, clientIp: envInfo.TCB_SOURCE_IP || envInfo.WX_CLIENTIP, data: newParams.capitalizeDataKey ? utils_1.capitalizeKey(newParams.data) : newParams.data });
        const resp = await cloud_api_1.wedaRequest(requestParams, { target: utils_1.getConfig('wedaTarget') });
        return resp;
    }
    catch (error) {
        if (error.original) {
            throw new utils_1.TCBError(error.original.Code, error.original.Message);
        }
        throw error;
    }
}
exports.fetchWeda = fetchWeda;
